@@ -2,7 +2,7 @@
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2005  Alexandru Csete.
+    Copyright (C)  2001-2006  Alexandru Csete.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -23,11 +23,11 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the
-          Free Software Foundation, Inc.,
-	  59 Temple Place, Suite 330,
-	  Boston, MA  02111-1307
-	  USA
+    along with this program; if not, visit http://www.fsf.org/
+ 
+ 
+ 
+ 
 */
 #ifndef GRIG_MENUBAR_H
 #define GRIG_MENUBAR_H 1
@@ -35,5 +35,8 @@
 
 GtkWidget *grig_menubar_create (void);
 
+void grig_menubar_force_tx_item (gboolean val);
+void grig_menubar_force_rx_item (gboolean val);
+
 
 #endif
